@@ -50,6 +50,7 @@ func NewRuleExpression(actionsCache *LocalActionsCache, workflowCache *LocalReus
 // VisitWorkflowPre is callback when visiting Workflow node before visiting its children.
 func (rule *RuleExpression) VisitWorkflowPre(n *Workflow) error {
 	rule.checkString(n.Name)
+	rule.checkString(n.RunName)
 
 	for _, e := range n.On {
 		switch e := e.(type) {
@@ -66,7 +67,7 @@ func (rule *RuleExpression) VisitWorkflowPre(n *Workflow) error {
 			rule.checkStrings(e.Cron)
 		case *WorkflowDispatchEvent:
 			ity := NewEmptyStrictObjectType()
-			for _, i := range e.Inputs {
+			for n, i := range e.Inputs {
 				rule.checkString(i.Description)
 				rule.checkString(i.Default)
 				rule.checkBool(i.Required)
@@ -81,7 +82,7 @@ func (rule *RuleExpression) VisitWorkflowPre(n *Workflow) error {
 				default:
 					ty = AnyType{}
 				}
-				ity.Props[i.Name.Value] = ty
+				ity.Props[n] = ty
 			}
 			rule.dispatchInputsTy = ity
 		case *RepositoryDispatchEvent:
@@ -100,7 +101,7 @@ func (rule *RuleExpression) VisitWorkflowPre(n *Workflow) error {
 				default:
 					ty = AnyType{}
 				}
-				ity.Props[n.Value] = ty
+				ity.Props[n] = ty
 
 				rule.checkString(i.Description)
 				rule.checkString(i.Default)
@@ -113,7 +114,7 @@ func (rule *RuleExpression) VisitWorkflowPre(n *Workflow) error {
 			if e.Secrets != nil {
 				sty := NewEmptyStrictObjectType()
 				for n, s := range e.Secrets {
-					sty.Props[n.Value] = StringType{}
+					sty.Props[n] = StringType{}
 					rule.checkString(s.Description)
 				}
 				rule.secretsTy = sty
@@ -985,7 +986,7 @@ func (rule *RuleExpression) guessTypeOfMatrixRow(r *MatrixRow) ExprType {
 	return ty
 }
 
-func (rule *RuleExpression) checkWorkflowCallOutputs(outputs map[*String]*WorkflowCallEventOutput, jobs map[string]*Job) {
+func (rule *RuleExpression) checkWorkflowCallOutputs(outputs map[string]*WorkflowCallEventOutput, jobs map[string]*Job) {
 	if len(outputs) == 0 || len(jobs) == 0 {
 		return
 	}
@@ -999,7 +1000,7 @@ func (rule *RuleExpression) checkWorkflowCallOutputs(outputs map[*String]*Workfl
 		} else {
 			p := make(map[string]ExprType, len(j.Outputs))
 			for n := range j.Outputs {
-				p[strings.ToLower(n)] = StringType{}
+				p[n] = StringType{}
 			}
 			o = NewStrictObjectType(p)
 		}
@@ -1068,7 +1069,7 @@ func typeOfActionOutputs(meta *ActionMetadata) *ObjectType {
 	}
 	props := make(map[string]ExprType, len(meta.Outputs))
 	for n := range meta.Outputs {
-		props[n] = StringType{}
+		props[strings.ToLower(n)] = StringType{}
 	}
 	return NewStrictObjectType(props)
 }
